@@ -234,10 +234,9 @@ class BuilderModel:
                 dictionary_yaml = yaml.safe_load(stream)
                 self.model_data = DataModelMagnet(**dictionary_yaml)
         elif case_model == 'circuit':
-            # Load yaml keys into DataModelCircuit dataclass
-            with open(self.file_model_data, "r") as stream:
-                dictionary_yaml = yaml.safe_load(stream)
-                self.circuit_data = DataModelCircuit(**dictionary_yaml)
+            Parser = ParserPSPICE(self.circuit_data)
+            Parser.readFromYaml(self.file_model_data)
+            self.circuit_data = Parser.circuit_data
         elif case_model == 'conductor':
             # Load yaml keys into DataModelConductor dataclass
             with open(self.file_model_data, "r") as stream:
@@ -293,52 +292,55 @@ class BuilderModel:
             nameFileSMIC = os.path.join(self.output_path, magnet_name + '_selfMutualInductanceMatrix.csv')  # full path of the .csv file with self-mutual inductances to write
 
             # Copy/edit the ROXIE map2d file
-            suffix = "_All"
-            if self.model_data.Options_LEDET.field_map_files.flag_modify_map2d_ribbon_cable == 1:
-                #     # [[...half_turn_length, Ribbon...n_strands],.....]
-                # TODO: geometry when conductor has a combination of ribbon and non-ribbon cables
+            if self.path_map2d:
+                suffix = "_All"
+                if self.model_data.Options_LEDET.field_map_files.flag_modify_map2d_ribbon_cable == 1:
+                    #     # [[...half_turn_length, Ribbon...n_strands],.....]
+                    # TODO: geometry when conductor has a combination of ribbon and non-ribbon cables
 
-                # List of flags that are True is the cable type is "Ribbon"
-                list_flag_ribbon = []
-                for i, cond in enumerate(self.model_data.CoilWindings.conductor_to_group):
-                    list_flag_ribbon.append(self.model_data.Conductors[cond - 1].cable.type == 'Ribbon')
+                    # List of flags that are True is the cable type is "Ribbon"
+                    list_flag_ribbon = []
+                    for i, cond in enumerate(self.model_data.CoilWindings.conductor_to_group):
+                        list_flag_ribbon.append(self.model_data.Conductors[cond - 1].cable.type == 'Ribbon')
 
-                nT_from_original_map2d, nStrands_inGroup_original_map2d, _, _, _, _, _, _ = getParametersFromMap2d(
-                    map2dFile=self.path_map2d, headerLines=self.model_data.Options_LEDET.field_map_files.headerLines,
-                    verbose=self.verbose)
+                    nT_from_original_map2d, nStrands_inGroup_original_map2d, _, _, _, _, _, _ = getParametersFromMap2d(
+                        map2dFile=self.path_map2d, headerLines=self.model_data.Options_LEDET.field_map_files.headerLines,
+                        verbose=self.verbose)
 
-                n_groups_original_file = len(nT_from_original_map2d)
-                geometry_ribbon_cable = []
+                    n_groups_original_file = len(nT_from_original_map2d)
+                    geometry_ribbon_cable = []
 
-                for i in range(n_groups_original_file):
-                    list = [None, None]
-                    list[0] = int(nStrands_inGroup_original_map2d[i])  # layers
-                    list[1] = nT_from_original_map2d[i]  # number of half-turns; in case it is not a ribbon cable, it is going to be ignored in the modify-ribbon-cable function
-                    geometry_ribbon_cable.append(list)
+                    for i in range(n_groups_original_file):
+                        list = [None, None]
+                        list[0] = int(nStrands_inGroup_original_map2d[i])  # layers
+                        list[1] = nT_from_original_map2d[i]  # number of half-turns; in case it is not a ribbon cable, it is going to be ignored in the modify-ribbon-cable function
+                        geometry_ribbon_cable.append(list)
 
-                if self.verbose:
-                    print('geometry_ribbon_cable: {}'.format(geometry_ribbon_cable))
+                    if self.verbose:
+                        print('geometry_ribbon_cable: {}'.format(geometry_ribbon_cable))
 
-                file_name_output = copy_modified_map2d_ribbon_cable(magnet_name,
-                                                                    self.path_map2d,
-                                                                    self.output_path, geometry_ribbon_cable,
-                                                                    self.model_data.Options_LEDET.field_map_files.flagIron,
-                                                                    self.model_data.Options_LEDET.field_map_files.flagSelfField,
-                                                                    list_flag_ribbon,
-                                                                    suffix=suffix, verbose=self.verbose)
+                    file_name_output = copy_modified_map2d_ribbon_cable(magnet_name,
+                                                                        self.path_map2d,
+                                                                        self.output_path, geometry_ribbon_cable,
+                                                                        self.model_data.Options_LEDET.field_map_files.flagIron,
+                                                                        self.model_data.Options_LEDET.field_map_files.flagSelfField,
+                                                                        list_flag_ribbon,
+                                                                        suffix=suffix, verbose=self.verbose)
 
-            elif self.model_data.Options_LEDET.field_map_files.flag_modify_map2d_ribbon_cable == 0 or self.model_data.Options_LEDET.field_map_files.flag_modify_map2d_ribbon_cable == None:
-                file_name_output = copy_map2d(magnet_name, self.path_map2d, self.output_path,
-                                              self.model_data.Options_LEDET.field_map_files.flagIron,
-                                              self.model_data.Options_LEDET.field_map_files.flagSelfField,
-                                              suffix=suffix, verbose=self.verbose)
+                elif self.model_data.Options_LEDET.field_map_files.flag_modify_map2d_ribbon_cable == 0 or self.model_data.Options_LEDET.field_map_files.flag_modify_map2d_ribbon_cable == None:
+                    file_name_output = copy_map2d(magnet_name, self.path_map2d, self.output_path,
+                                                  self.model_data.Options_LEDET.field_map_files.flagIron,
+                                                  self.model_data.Options_LEDET.field_map_files.flagSelfField,
+                                                  suffix=suffix, verbose=self.verbose)
 
-            self.map2d_file_modified = os.path.join(self.output_path, file_name_output)
+                self.map2d_file_modified = os.path.join(self.output_path, file_name_output)
+            else:
+                self.map2d_file_modified = None
 
             # Copy the additional geometry and magnetic field csv file, if defined in the input file
             if self.model_data.Options_LEDET.simulation_3D.sim3D_flag_Import3DGeometry == 1:
                 name_geometry_csv_file = magnet_name + '_' + str(
-                    self.conductor_data.Options_LEDET.simulation_3D.sim3D_import3DGeometry_modelNumber) + '.csv'
+                    self.model_data.Options_LEDET.simulation_3D.sim3D_import3DGeometry_modelNumber) + '.csv'
                 input_path_full = os.path.join(self.path_magnet, name_geometry_csv_file)
                 output_path_full = os.path.join(self.output_path, name_geometry_csv_file)
                 shutil.copy2(input_path_full, output_path_full)
@@ -520,8 +522,7 @@ class BuilderModel:
             Path(self.dump_all_path).mkdir(parents=True)
 
         # Write output .yaml file
-        dump_all_full_path = os.path.join(dump_all_path,
-                                          self.model_data.GeneralParameters.magnet_name + '_all_data.yaml')
+        dump_all_full_path = os.path.join(dump_all_path, self.model_data.GeneralParameters.magnet_name + '_all_data.yaml')
         # with open(dump_all_full_path, 'w') as outfile:
         #     yaml.dump(all_data_dict, outfile, default_flow_style=False, sort_keys=False)
         dict_to_yaml(all_data_dict, dump_all_full_path, list_exceptions=['Conductors'])
