@@ -1,4 +1,4 @@
-def lookupModelDataToLEDET(key: str, mode='data2ledet'):
+def lookupModelDataToLEDET(key: str, mode: str = 'data2ledet'):
     """
         Retrieves the correct LEDET parameter name for a DataModelMagnet input
         The argument mode is used to define the direction, either "data2ledet" or "ledet2data"
@@ -7,8 +7,6 @@ def lookupModelDataToLEDET(key: str, mode='data2ledet'):
         'GeneralParameters.T_initial': 'T00',
         'GeneralParameters.magnetic_length': 'l_magnet',  # useful when case_model='magnet'
         'GeneralParameters.length_busbar': 'l_magnet',  # useful when case_model='conductor'
-        'GeneralParameters.magnet_inductance.fL_I': 'fL_I',
-        'GeneralParameters.magnet_inductance.fL_L': 'fL_L',
 
         'CoilWindings.conductor_to_group': 'type_to_group',  # TODO: change name, or make it obsolete
         # Note that nT is NOT defined here (at the moment it is read from map2d file)
@@ -17,17 +15,6 @@ def lookupModelDataToLEDET(key: str, mode='data2ledet'):
         'CoilWindings.half_turn_length': 'l_mag_inGroup',
         'CoilWindings.electrical_pairs.group_together': 'elPairs_GroupTogether',
         'CoilWindings.electrical_pairs.reversed': 'elPairs_RevElOrder',
-        'CoilWindings.heat_exchange.heat_exchange_max_distance': 'heat_exchange_max_distance',
-        'CoilWindings.heat_exchange.iContactAlongWidth_pairs_to_add': 'iContactAlongWidth_pairs_to_add',
-        'CoilWindings.heat_exchange.iContactAlongWidth_pairs_to_remove': 'iContactAlongWidth_pairs_to_remove',
-        'CoilWindings.heat_exchange.iContactAlongHeight_pairs_to_add': 'iContactAlongHeight_pairs_to_add',
-        'CoilWindings.heat_exchange.iContactAlongHeight_pairs_to_remove': 'iContactAlongHeight_pairs_to_remove',
-        'CoilWindings.heat_exchange.th_insulationBetweenLayers': 'th_insulationBetweenLayers',
-
-        'CoilWindings.multipole.alphaDEG_ht': 'alphasDEG',
-        'CoilWindings.multipole.rotation_ht': 'rotation_block',
-        'CoilWindings.multipole.mirror_ht': 'mirror_block',
-        'CoilWindings.multipole.mirrorY_ht': 'mirrorY_block',
 
         # TODO: pancake, solenoid, CCT_Straight, CCT_curve parameters
 
@@ -164,6 +151,23 @@ def lookupModelDataToLEDET(key: str, mode='data2ledet'):
 
         'Options_LEDET.time_vector.time_vector_params': 'time_vector_params',
 
+        'Options_LEDET.magnet_inductance.flag_calculate_inductance': 'flag_calculate_inductance',
+        'Options_LEDET.magnet_inductance.overwrite_inductance_coil_sections': 'overwrite_inductance_coil_sections',
+        'Options_LEDET.magnet_inductance.LUT_DifferentialInductance_current': 'fL_I',
+        'Options_LEDET.magnet_inductance.LUT_DifferentialInductance_inductance': 'fL_L',
+
+        'Options_LEDET.heat_exchange.heat_exchange_max_distance': 'heat_exchange_max_distance',
+        'Options_LEDET.heat_exchange.iContactAlongWidth_pairs_to_add': 'iContactAlongWidth_pairs_to_add',
+        'Options_LEDET.heat_exchange.iContactAlongWidth_pairs_to_remove': 'iContactAlongWidth_pairs_to_remove',
+        'Options_LEDET.heat_exchange.iContactAlongHeight_pairs_to_add': 'iContactAlongHeight_pairs_to_add',
+        'Options_LEDET.heat_exchange.iContactAlongHeight_pairs_to_remove': 'iContactAlongHeight_pairs_to_remove',
+        'Options_LEDET.heat_exchange.th_insulationBetweenLayers': 'th_insulationBetweenLayers',
+
+        'Options_LEDET.conductor_geometry_used_for_ISCL.alphaDEG_ht': 'alphasDEG',
+        'Options_LEDET.conductor_geometry_used_for_ISCL.rotation_ht': 'rotation_block',
+        'Options_LEDET.conductor_geometry_used_for_ISCL.mirror_ht': 'mirror_block',
+        'Options_LEDET.conductor_geometry_used_for_ISCL.mirrorY_ht': 'mirrorY_block',
+
         'Options_LEDET.field_map_files.Iref': 'Iref',
         'Options_LEDET.field_map_files.flagIron': 'flagIron',
         'Options_LEDET.field_map_files.flagSelfField': 'flagSelfField',
@@ -289,15 +293,25 @@ def lookupModelDataToLEDET(key: str, mode='data2ledet'):
     return returned_key
 
 
-def lookupWindings(key: int):
+def lookupWindings(key: int, mode: str = 'data2ledet'):
     """
         Retrieves the correct LEDET parameter name for a DataModelMagnet input
     """
-    typeWindings = {
-        0: 'multipole',
-        1: 'solenoid'
+    magnet_type = {
+        'multipole': 0,
+        'solenoid' : 1,
+        'CCT'      : 2,
+        'busbar'   : 101
     }
-    return typeWindings[key] if key in typeWindings else None
+
+    if mode == 'data2ledet':
+        returned_key = magnet_type[key] if key in magnet_type else None
+    elif mode == 'ledet2data':
+        # Generate an inverted dictionary
+        lookup_inverted = {v: k for k, v in magnet_type.items()}
+        returned_key = lookup_inverted[key] if key in lookup_inverted else None
+
+    return returned_key
 
 
 def lookupSuperconductor(key: str):
